import argparse


def get_arguments():
    parser = argparse.ArgumentParser(
        description="Sort Your Life Out! Python Pomodoro Timer"
    )
    parser.add_argument("-w", "--work_time", help="Set the work time length", type=int)
    parser.add_argument(
        "-r", "--rest_time", help="Set the rest time length", type=int
    )
    parser.add_argument("-d", '--double_speed', dest='double_speed', action='store_true')
    parser.set_defaults(double_speed=False)
    return parser.parse_args()



import os


def get_first_file_in_directory(path: str):
    return path + os.listdir(path)[0]


def clear_screen():
    os.system("cls" if os.name == "nt" else "clear")


def mins_to_secs(minutes: int):
    return minutes * 60


def flip_mode(mode: str):
    if mode == 'work':
        return 'rest'
    else:
        return 'work'
